# KebechetMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**message_justification** | **int** |  | [optional]
**package_index** | **str** |  | [optional]
**package_name** | **str** |  | [optional]
**package_version** | **str** |  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

